@@ -7,9 +7,12 @@ import glob
 
 setup(
       name="opendict",
-      version="0.6.3",
+      version="0.6.5",
       zipfile=None,
       package_dir = {"": "lib"},
-      windows=["opendict.py"],
+      windows = [{
+            "script":"opendict.py",
+            "icon_resources": [(1, "win32/opendict.ico")]
+            }],
       data_files=[("pixmaps", glob.glob("pixmaps/\\*.png"))],
 )
